#! /bin/ksh
#
# Inspect startup script
# ----------------------
#

# debbug:
# set -x 

# To enable overwriting of existing files
# we need to unset the `noclobber' option
set +o noclobber

# Set vars from configuration file

BASEPROG="pss_start"
USAGE="Usage: `basename $0` [-cpmjr] [-d homedir] [-k sid] [-P program] [parms...]"
if [ "`uname`" = "Linux" ] ; then
   export GETOPT_COMPATIBLE=YES
fi
FLAGS="-egbjswpcmrd:k:fP:ZR"

cd `dirname "$0"`
path=`pwd`
pss_check_oracle_home=FALSE

#-------------------------------------------------------------------
#-------------------------------------------------------------------
#-------------------------------------------------------------------
# define OS & CPU type in order by select the appropriate offsets 
# file for running platform, those variables is used in pcs process.
# adding by Liad Hacmon. 4/5/2006
OS=`uname -s`

case "$OS" in

(AIX)
	PROCESSOR_ARCHITECTURE=PowerPC
    ;;

(HP-UX)
	# HP-UX cpu types : ia64 or 9000
	PROCESSOR_ARCHITECTURE=`uname -m`
        if [ "$PROCESSOR_ARCHITECTURE" != "ia64" ] ; then
		PROCESSOR_ARCHITECTURE=9000	
	fi
    ;;

(SunOS)
	PROCESSOR_ARCHITECTURE=`uname -p`
    ;;

(Linux)
	PROCESSOR_ARCHITECTURE=`uname -m`
    ;;

(OSF1)
	PROCESSOR_ARCHITECTURE=`uname -m`
    ;;

(*) echo "OS $OS not supported."
    exit
    ;;
esac

export OS
export PROCESSOR_ARCHITECTURE

#-------------------------------------------------------------------
#-------------------------------------------------------------------
#-------------------------------------------------------------------
# In case of EMC extansion the defualt is to re-map the datafiles at the collector startup process
export pss_enable_emc_mapping=YES
#-------------------------------------------------------------------

. $path/precvars.sh

# After the call to precvars.sh, create the logs folder. This is for errors created prior logger initialization.
# For example "Run root.sh..." PR 960759, Ram Cohen 31/01/2007.
mkdir -p $LOG 2> /dev/null

if [ $OS = "SunOS" ] ; then
	# Get the Solaris version (the second number of 5.8 5.9 5.10 etc). Ram Cohen, Nov 2007.
	pss_solaris_version=`uname -r | cut -f2 -d '.'`
	
	#########################
	# For Sun systems we need to check 
	# if the system configure with ISM
	# Adding By Liad Hacmon - 12/27/2006
	check_for_ism
	#########################
fi

# Update Oracle Home if requested
if [ $pss_check_oracle_home = "TRUE" ] ; then
	# oratab file's location is different in Sun
	if [ `uname -s` = "SunOS" ] ; then
		oratab_file="/var/opt/oracle/oratab"
	else
		oratab_file="/etc/oratab"
	fi

	# Get the Oracle Home from oratab
	new_oracle_home=`grep $oracle_sid: $oratab_file | grep -v "#" | cut -d : -f 2`

	# Check existance of new Oracle Home
	if [ -d $new_oracle_home ] ; then
		if [ -f $new_oracle_home/bin/oracle ] ; then

			# If different than registry update Oracle Home
			if [ $new_oracle_home != $oracle_home ] ; then
				export oracle_home=$new_oracle_home
			fi
		fi
	fi
fi

#export I3 common time environment variable
export I3_ROOT_FOLDER=`echo $i3_base_dir`

if [ $collector_counter != 0 -a $collector_counter != 1 ] ; then
   echo "Can't start multiple agents in one execution"
   exit 11
fi

if [ "$fl_presto" = true ] ; then
   fl_conn=false
   fl_collect=false
fi

# Check that I4O agents are started from their owner.

# Set unix environment

umask 002

#
# Start I4O FP
#
if [ "$fl_fp" = true ] ; then
   cd $i3_base_dir

   server=''
   case "`uname -s`" in
        HP-UX)     server='-server';;
        SunOS)     server='-server';;
   esac
   
   out="`infra/bin/psin_process_status.sh OR 1 2>/dev/null`"
   stat=`echo $out`
   case "$stat" in
      (*SUCCESS*START*) 
          echo $START_ALREADY_UP
          ;;
      (*SUCCESS*STOP*)  
          # infra/bin/psin_start_product.sh OR 0 logs/oracle.focal.out $server -Xms8m -Xmx256m -DTZ=$TZ com.precise.oracle.fp.FpMain 2>/dev/null
          ./infra/bin/psin_start_product_by_xml.sh OR 0 ./products/oracle/bin/psor_fp_init.xml
	  set -m
          echo $START_STARTED
          f_create_sentry_file "FP" "#"
          ;;
      (*) echo $STATUS_UNKNOWN
          exit 10
          ;;
   esac

   exit
fi

if [ "$oracle_sid" = "" ] ; then
   echo "Please specify an ORACLE_SID (with the -k option)."
   exit 11
fi

# create support file 
if [ "$fl_support" = true ] ; then
   cd $i3_base_dir
   (tar cf - /etc/system ./products/oracle/config.xml ./products/oracle/helper.xml `find ./infra/listener/* -name '*.xml' -print -o -name '*.trace' -print` `find ./logs/ -name '*.xml' -print` `find ./* -name '*.log' -print -o -name '*.trc' -print -o -name '*.cfg' -print -o -name '*.init' -print -o -name '*.bin' -print -o -name '*.txt' -print  | grep -v sqlText | grep -v savant ` | compress -c > ./support/support.tar.Z) > tar.log 2>&1
   exit 0
fi

if [ "$fl_root" = true ] && [ "`$pss_root_dir/install/root.sh -check`" = 1 ] ; then
   ulog $0 E 2 $$ "Run root.sh as user root to set image protection."
   if [ "$fl_collector_check" = true ] ; then
	echo "~END ERROR~"
   fi
   ulog $0 E 2 $$ "Run root.sh as user root to set image protection." >> $LOG_FILE
   exit -1
fi

#check that user group is like oracle group
if [ ! -z "$oracle_home" ] && [ `uname -s` != "Linux" ] ; then
   if [ -d $oracle_home  ] ; then
      id_cmd="id"
      if [ `uname` = SunOS ] ; then
         id_cmd="id -a `/usr/xpg4/bin/id -un`"
      fi;

      oracle_group=`ls -ln $oracle_home/bin/oracle | awk '{print $4}'`
      $id_cmd | grep "$oracle_group(" > /dev/null

      if [ $? != 0 ] ; then
         ulog $0 E 2 $$ "User group is not like oracle group" $oracle_group 
         exit -1
      fi
   fi
fi

# check if symmetrix is up 
if [ "$fl_sym_up" = true ] ; then
      if [ "$PCS_PID" -gt 0 ] ; then
         echo $STATUS_RUNNING
      else
         echo $STATUS_STOPED
      fi
      exit 0
fi

# check if the collector is in restart mode
if [ "$RESTART_PID" -gt 0 ] ; then
	ulog $0 E 2 $$ "Collector is in RESTART MODE, cannot start it right now. Please check if the collector is up in 5 more minutes."
	ulog $0 E 2 $$ "Collector is in RESTART MODE, cannot start it right now. Please check if the collector is up in 5 more minutes." >> $LOG_FILE
	echo $STATUS_STARTING
	exit -1
# check if collector is up
elif [ "$fl_collector_up" = true ] ; then
   if [ "$STRT_PID" -gt 0 ] ; then
      echo $STATUS_STARTING
   elif [ "$PCS_PID" -gt 0 ] && [ "$RX_PID" -gt 0 ] && (  [ "$pss_interpoint" = 0 ] || [ "$pss_interpoint" = 5 ] || [ "$pss_interpoint" = 9 ]  || [ "$APP_PID" -gt 0 ] ) ;  then 
      echo $STATUS_RUNNING
   elif [ "$PCS_PID" -gt 0 ] || [ "$RX_PID" -gt 0 ] || [ "$APP_PID" -gt 0 ] ; then
      echo $STATUS_PART_UP
   elif [ "$PCS_PID" -eq 0 ] && [ "$RX_PID" -eq 0 ] && [ "$APP_PID" -eq 0 ] ; then
      echo $STATUS_STOPED
   else
      echo $STATUS_UNKNOWN
   fi
   exit 
fi

if [ "$fl_collect" = true ] ; then
   if [ "$STRT_PID" -gt 0 ] ; then
      echo $START_ALREADY_STARTING
      exit
   else
      if [ "$fl_prepare" = false ] ; then
         if [ "$PCS_PID" -gt 0 ] && [ "$RX_PID" -gt 0 ] && (  [ "$pss_interpoint" = 0 ] || [ "$pss_interpoint" = 5 ] || [ "$pss_interpoint" = 9 ]  || [ "$APP_PID" -gt 0 ] ) ;  then 
            echo $START_ALREADY_UP
	    exit
         elif [ "$PCS_PID" -gt 0 ] || [ "$RX_PID" -gt 0 ] || [ "$APP_PID" -gt 0 ] ; then
	    echo $START_PART_UP
	    exit
         elif [ "$PCS_PID" -eq 0 ] && [ "$RX_PID" -eq 0 ] && [ "$APP_PID" -eq 0 ] ; then
	    echo $STATUS_STARTING
         else
	    echo $STATUS_UNKNOWN
	    exit
         fi
      else
         if [ "$PCS_PID" -gt 0 ] && [ "$RX_PID" -gt 0 ] && [ "$PREPARE_PID" -gt 0 ] && ( [ "$pss_interpoint" = 0 ] || [ "$pss_interpoint" = 5 ] || [ "$pss_interpoint" = 9 ]  || [ "$APP_PID" -gt 0 ] ) ;  then 
            echo $START_ALREADY_UP
	    exit
         elif [ "$PCS_PID" -gt 0 ] || [ "$RX_PID" -gt 0 ] || [ "$PREPARE_PID" -gt 0 ] || [ "$APP_PID" -gt 0 ] ; then
	    echo $START_PART_UP
	    exit
         elif [ "$PCS_PID" -eq 0 ] && [ "$RX_PID" -eq 0 ] && [ "$PREPARE_PID" -eq 0 ] && [ "$APP_PID" -eq 0 ] ; then
	    echo $STATUS_STARTING
         else
	    echo $STATUS_UNKNOWN
	    exit
         fi
      fi
   fi
fi

if [ -n "$fl_prog" ] ; then
   $fl_prog $*
   exit
fi

#####################################################
# from this point on, its all starting the collector

function fexit {
    if [ $STRT_PID -gt 0 ] ; then
       kill $STRT_PID 2>/dev/null
    fi
    rm $STRT_FILE 2>/dev/null
    exit
}

STRT_PID=0
trap fexit EXIT
# Ami Levin, August 21 2006, use process number (acquired by $$) instead of pss_find
echo $$> $STRT_FILE 2>/dev/null


# kill restart.sh
find_pss_restart_pid

#    Remove ipc resources
if [ -n "$pss_shared_memory_id" ] ; then
   ipcrm -M $pss_shared_memory_id 1>/dev/null 2>&1
   ipcrm -S $pss_shared_memory_id 1>/dev/null 2>&1
	# Tsiyon Sadiky, 3/10/2004. 
	# In some versions of linux, only the deprecated format is supported
	# if the former format didn't work, use the old format
   if [ -n "$pss_shared_memory_id" ] && [ "`uname`" = "Linux" ] ; then
         ipcrm shm `ipcs -m | grep $pss_shared_memory_id | cut -d" " -f2` 1>/dev/null 2>&1
         ipcrm sem `ipcs -s | grep $pss_shared_memory_id | cut -d" " -f2` 1>/dev/null 2>&1
   fi	
fi

# set pss_oracle_group
if [ "$oracle_sid" != "symmetrx" ]; then
    export pss_oracle_group=`ls -ln $oracle_home/bin/oracle | awk '{print $4}'`
fi

# Read some values from Oracle tables


# Fixed by postExtract.sh
#if [ "`uname`" = "AIX" ] ; then
#  if [ "`uname -v`" = "5" ] ; then
#	export LD_LIBRARY_PATH=$pss_root_dir/lib/aix5L/lib_$pss_start_version
#  else
#	export LD_LIBRARY_PATH=$pss_root_dir/lib/aix433/lib_$pss_start_version
#     
#  fi
#fi	

export LIBPATH=$LD_LIBRARY_PATH
export SHLIB_PATH=$LD_LIBRARY_PATH

# This file deletion is in order to work with the objid tree a more efficient way. pss_start.8i/9i checks what is the max object id
# and according to that updates the b-tree that includes the object ids. When these files are not existed the pss_start.8i/9i assumes
# that this is the first time the collector is running and instead of adding the object ids that gathered since the last time it updated
# these files it just create them again from scratch. It's proven that sometimes it's more efficient to build them from scratch than appending
# the delta. For more information see case 280-585-743. Ami Levin 9/4/2006

if [ -f $DATA/objidTemp.bin ] ; then
	\rm -f $DATA/objidTemp.bin
fi

if [ -f $DATA/objidTemp.ind ] ; then
	\rm -f $DATA/objidTemp.ind
fi

if [ "$fl_conn" = true ] ; then
   old_dir=`pwd`
   
   # create XML for psor_start
   psor_start_xml_file=$ETC/psor_start.xml
   echo "<root>" > $psor_start_xml_file
   echo "<oracle-sid>$oracle_sid</oracle-sid>">> $psor_start_xml_file
   echo "<pss-instance-id>$pss_instance_id</pss-instance-id>">> $psor_start_xml_file
   echo "<pss-context>$pss_context</pss-context>">> $psor_start_xml_file
   echo "<pss-local-host-name>$pss_local_host_name</pss-local-host-name>">> $psor_start_xml_file
   echo "<pss-temp-dir>$pss_temp_dir</pss-temp-dir>">> $psor_start_xml_file
   echo "</root>" >> $psor_start_xml_file
   
   cd ..
   if [ "$fl_collector_check" = true ] ; then
	OUTPUTFILE=$VERIFICATION_TRC
   else
	OUTPUTFILE=/dev/null
   fi

   curr_dir=`pwd`
   cd $i3_base_dir
   wait_time=30
   interval=5
   result=$(./infra/bin/psin_http_requestor -dp -x or-pss-start IN < $ETC/psor_start.xml 2>>$OUTPUTFILE )
   status=$?
   while [ $status -ne 0 -a  $wait_time -ge 0 ] ; do
	wait_time=$(($wait_time-$interval))
	sleep $interval
	result=$(./infra/bin/psin_http_requestor -dp -x or-pss-start IN < $ETC/psor_start.xml 2>/dev/null )
	status=$?
   done
   if [ $status -ne 0 ] ; then 
	ulog $0 W 2 $$ "Can't connect to Precise listener, verify that the listener is up."
	ulog $0 W 2 $$ "Can't connect to Precise listener, verify that the listener is up." >> $LOG_FILE
	result=0
   fi

   cd $curr_dir

   restart=$result
   cd $old_dir
   case $restart in
      (0) ;;               # OK. continue.
      (2) pss_restart.sh & # connect error. retry.
          exit 11
          ;;
      (*) exit 10          # error.
          ;;
   esac

   # Titan 281-185-828 (Amkor): When having Interpoint for SAP, the startup process is very long (more then 20 minutes).
   # Solution: we take out from pss_start (bin) the process of building this objects file, and move it to pss_start.sh script. 
   # This gives us a quick collector startup, while the building of the objects file is done asynchronously (to storage processes and pcs, rx)
   # right after pss_start (bin) finishes. Note: the fix is for UNIX only. Ram Cohen, 04/09/2007 */
   cd $i3_base_dir
   (./infra/bin/psin_http_requestor -dp -x or-pss-start-objects IN < products/oracle/$oracle_sid/etc/psor_start.xml >/dev/null 2>&1 ; ./infra/bin/psin_http_requestor -dp -x or-pss-start-plsql IN < products/oracle/$oracle_sid/etc/psor_start.xml >/dev/null 2>&1 ) &  
   cd $old_dir

   if [ "`uname`" = "AIX" ] ; then
      ksmsCmd=""
      if [ -d $oracle_home/lib64 ] ; then
         if [ -f $oracle_home/lib64/ksms.imp ] ; then
            ksmsCmd="cat $oracle_home/lib64/ksms.imp" ;
         fi
      elif [ -d $oracle_home/lib ] ; then
         if [ -f $oracle_home/lib/ksms.imp ] ; then
            ksmsCmd="cat $oracle_home/lib/ksms.imp" ;
         fi
      fi

      if [ -z "$ksmsCmd" ] && [ -f $oracle_home/bin/genksms ] ; then
         ksmsCmd="$oracle_home/bin/genksms" ;
      fi

      if [ ! -z "$ksmsCmd" ] ; then
         $ksmsCmd | egrep "(ksmsgf_)|(ssskgminfo_)" | sed 's/_ 0x/=/' | sed 's/ksmsgf/pss_ksmsgf/' >> precise.init
      fi
   fi   
fi


readVar $INIT_FILE
export pss_index_count
export pss_sample_schema_track
export pss_schema_track_interval
export pss_oracle_first_sga_addr
export pss_oracle_max_object_id
export pss_oracle_up
export pss_full_full_oracle_version
export pss_oracle_processes
export pss_oracle_proc_table_addr
export pss_oracle_sessions
export pss_oracle_sess_table_addr
export pss_oracle_sess_table_second
export pss_lgwr_pid
export pss_oracle_start_time
export pss_os_start_time
export pss_full_oracle_version
export pss_ora_db_block_size
export pss_enqueue_event
export pss_enqTx_event
export pss_enqTm_event
export pss_enqSt_event
export pss_sqlNet_BrRe
export pss_sqlNet_MsgFrClient
export pss_buffer_busy_wait_event_parm
export pss_read_by_other_session_event_parm
export pss_virtual_circuit_event_parm
export pss_oracle_bg_processes
export pss_latch_free_event_parm
export pss_waitListLatchFree_event_parm
export pss_max_events
export pss_ps_installed
export ksmsgf
export ssskgminfo
export pss_db_files
export pss_ksmsgf
export pss_kftbkes
export pss_kfthahes
export pss_krtbkes
export pss_krthahes
export pss_kcbqhb
export pss_kqrsga
export pss_kqrsga_users
export pss_kqrsga_object
export pss_kcbnhb
export pss_kcbnhbsft
export pss_kcbhlm
export pss_kcbhll
export pss_kcblhbpseg
export pss_kcbbktmsk
export pss_siebel_srvrmgr_host
export pss_siebel_srvrmgr_port
export pss_sum_stats
export pss_sum_events
export pss_oracle_bits
export OS
export PROCESSOR_ARCHITECTURE
export pss_enabled_ism
export pss_solaris_version
export SYMM64BIT

# OVERRIDE dbfiles.txt
if [ -f "$pss_root_dir/$oracle_sid/etc/dbfiles.override" ]; then
        cp "$pss_root_dir/$oracle_sid/etc/dbfiles.override" "$pss_root_dir/$oracle_sid/etc/dbfiles.txt"
fi

# make support file named <i3-root>/products/oracle/<sid>/log/<sid>_offsets_filename.log
# that indicated the names to the external offsets file for the appropriate instance.
print_support_offsets_filenames

# Added By Lior Shapsa
if [ $offset_file_exist = 0 ] ; then
   ulog $0 E 2 $$ "Oracle Version Is Not Supported (Offsets File Doesn't Exist). Please Contact Precise Support" >> $LOG_FILE
   echo "Oracle Version Is Not Supported (Offsets File Doesn't Exist). Please Contact Precise Support"
   exit
fi

# For HP-UX 11 - check if SID uses Memory windows:
memWinId=`getMemWinId`

# if silent mode - start only pss_rx and pss_pcs.
# In this case (fl_collector_check=FALSE)-don't build files extent tables.
# Build files extent table

if [ "$pss_vx_installed" = "YES" ] && [ "$fl_collector_check" = false ]  ; then
       PATH=$PATH:/usr/sbin            # vgdisplay , lvdisplay, fsdb, ioscan, diskinfo
       PSS_VX=pss_vx
   
   # Check that HiScan dir is correct, and HiScan exe exists. Ram Cohen 23/01/2007 811689 
   if [ "$pss_hds_installed" = "YES" ] ; then
      if [ ! -d $pss_hds_hiscan_dir ] ; then
         ulog $0 E 2 $$ "HDS Hiscan dir $pss_hds_hiscan_dir does not exist."
         ulog $0 E 2 $$ "HDS Hiscan dir $pss_hds_hiscan_dir does not exist." >> $LOG_FILE
      elif [ ! -f $pss_hds_hiscan_dir/HiScan ] ; then
         ulog $0 E 2 $$ "HDS 'Hiscan' executable does not exist in $pss_hds_hiscan_dir."
         ulog $0 E 2 $$ "HDS 'Hiscan' executable does not exist in $pss_hds_hiscan_dir." >> $LOG_FILE
      fi
   fi

       if [ "`uname`" = "AIX" ] ; then
          case "x${pss_oracle_bits:-}" in 
             (x32) osver=`uname -s`_`uname -v``uname -r`
                   PSS_VX=pss_vx.32bit.$osver
                   ;;
             (x64) if [ "`uname -v`" -ge "5" ] ; then
                      PSS_VX=pss_vx.64bit.AIX_51
                   fi
                   ;;
             (*)  echo "please add pss_oracle_bits=32/64 to your cfg..."
                  exit
                  ;;
           esac
       fi
       $PSS_VX -startup -i $i3_base_dir_inode &   # dynamic mapping - do not wait for mapping to finish.
       if [ $? -ne 0 ] ; then
           pss_vx_installed=NO
           pss_xp_installed=NO
           pss_hds_installed=NO
           pss_ess_installed=NO
       fi
fi

if [ "$pss_xp_installed" = "YES" ] && [ "$pss_vx_installed" != "YES" ] && [ "$fl_collector_check" = false ] ; then
   if [ "$fl_collect" = true ] || [ "$fl_old_lsnr" = true ] && [ "$fl_iomap" = true ]; then
       PATH=$PATH:/usr/sbin            # vgdisplay , lvdisplay, fsdb, ioscan, diskinfo
       PSS_XP=pss_xp
       if [ "`uname`" = "AIX" ] ; then
          case "x${pss_oracle_bits:-}" in 
             (x32) if [ "`uname -v`" -ge "5" ] ; then
			PSS_XP=pss_xp.32bit.AIX_51
		   else
			PSS_XP=pss_xp.32bit.AIX_43
		   fi
                   ;;
	     (x64) if [ "`uname -v`" -ge "5" ] ; then
                      PSS_XP=pss_xp.64bit.AIX_51
                   fi
                   ;;
             (*)  echo "please add pss_oracle_bits=32/64 to your cfg..."
                  exit
                  ;;
           esac
       fi
       $PSS_XP -startup -i $i3_base_dir_inode &   # dynamic mapping - do not wait for mapping to finish.
       if [ $? -ne 0 ] ; then
           pss_xp_installed=NO
       fi
    fi
fi

if [ "$pss_hds_installed" = "YES" ] && [ "$pss_vx_installed" != "YES" ] && [ "$fl_collector_check" = false ] ; then
   # Check that HiScan dir is correct, and HiScan exe exists. Ram Cohen 23/01/2007 811689 
   if [ ! -d $pss_hds_hiscan_dir ] ; then
      ulog $0 E 2 $$ "HDS Hiscan dir $pss_hds_hiscan_dir does not exist."
      ulog $0 E 2 $$ "HDS Hiscan dir $pss_hds_hiscan_dir does not exist." >> $LOG_FILE
   elif [ ! -f $pss_hds_hiscan_dir/HiScan ] ; then
      ulog $0 E 2 $$ "HDS 'Hiscan' executable does not exist in $pss_hds_hiscan_dir."
      ulog $0 E 2 $$ "HDS 'Hiscan' executable does not exist in $pss_hds_hiscan_dir." >> $LOG_FILE
   fi

   if [ "$fl_collect" = true ] || [ "$fl_old_lsnr" = true ] && [ "$fl_iomap" = true ]; then
       PSS_XP=pss_xp
       if [ "`uname`" = "AIX" ] ; then
          case "x${pss_oracle_bits:-}" in 
             (x32) if [ "`uname -v`" -ge "5" ] ; then
			PSS_XP=pss_xp.32bit.AIX_51
		   else
			PSS_XP=pss_xp.32bit.AIX_43
		   fi
                   ;;
             (x64) if [ "`uname -v`" -ge "5" ] ; then
                      PSS_XP=pss_xp.64bit.AIX_51
                   fi
                   ;;
             (*)  echo "please add pss_oracle_bits=32/64 to your cfg..."
                  exit
                  ;;
           esac
       fi
       $PSS_XP -startup &   # dynamic mapping - do not wait for mapping to finish.
       if [ $? -ne 0 ] ; then
           pss_hds_installed=NO
       fi
   fi
fi

if [ "$pss_ess_installed" = "YES" ] && [ "$pss_vx_installed" != "YES" ] && [ "$fl_collector_check" = false ] ; then
   if [ "$fl_collect" = true ] || [ "$fl_old_lsnr" = true ] && [ "$fl_iomap" = true ]; then
       PATH=$PATH:/usr/sbin            # required by IBM lssdd
       PSS_XP=pss_xp
       if [ "`uname`" = "AIX" ] ; then
          case "x${pss_oracle_bits:-}" in 
             (x32) if [ "`uname -v`" -ge "5" ] ; then
			PSS_XP=pss_xp.32bit.AIX_51
		   else
			PSS_XP=pss_xp.32bit.AIX_43
		   fi
                   ;;
             (x64) if [ "`uname -v`" -ge "5" ] ; then
                      PSS_XP=pss_xp.64bit.AIX_51
                   fi
                   ;;
             (*)  echo "please add pss_oracle_bits=32/64 to your cfg..."
                  exit
                  ;;
           esac
       fi
       $PSS_XP -startup &   # dynamic mapping - do not wait for mapping to finish.
       if [ $? -ne 0 ] ; then
           pss_ess_installed=NO
       fi
   fi
fi


# Run inspect sampler

if [ $memWinId -ne 0 ] ; then
   memWinCmd="setmemwindow -i $memWinId -j -n"
else 
   memWinCmd=""
fi

if [ "$fl_collect" = true ] ; then
# Added local ipcs witth suid flag for linux with huge TLB
if [ "`uname`" = "Linux" ] ; then
   IPCS=$pss_root_dir/bin/ipcs
else
   IPCS=ipcs
fi
   # list all shm segments
   ######################################################
   ## Drorg 29/10				       ##
   ##						       ##
   ## This is due to a stupid Linux bug , that for     ##
   ## an unknown reason , sometime the redirection to  ##
   ## a directory that have more than 61 characters    ##
   ## doesnt work , so we need to cd to the directory  ##
   ######################################################
   if [ "`uname`" = "Linux" ] ; then 
      PWD_OLD=`pwd`
      cd $ETC
       $IPCS -m | grep -v 'dest\>' > ipcs.init
      cd $PWD_OLD
   else
      $IPCS -m >$IPCS_FILE
   fi

   case "x${pss_oracle_bits:-}" in 
      (x32) PCS=pss_pcs.32bit
           if [ `uname` = HP-UX ] && [ "`getconf _SC_KERNEL_BITS 2>/dev/null`" = 64 ] ; then 
              PCS=pss_pcs.32bit.hp64bit
           fi;;
      (x64) PCS=pss_pcs.64bit
		 if [ `uname` = Linux ] && [ "`uname -m`" = "x86_64" ] ; then
			PCS=pss_pcs.64bit.amd64
		 fi
	   if [ `uname` = AIX ] && [ "`uname -v`" -ge "5" ] ; then
	      PCS=pss_pcs.64bit.aix51
	   fi
	   if [ `uname` = HP-UX ] && [ "`uname -m`" = "ia64" ] ; then
              PCS=pss_pcs.64bit.hpit
            fi
	    if [ "`uname`" = SunOS ] && [ "`uname -p`" = "i386" ] ; then
             PCS=pss_pcs.64bit.SunOs.amd           
           fi;;
      (*)  echo "please add pss_oracle_bits=32/64 to your cfg..."
           exit;;
   esac

   if [ "$fl_collector_check" = true ] ; then
	 $memWinCmd $PCS -k $oracle_sid -i $i3_base_dir_inode 1>>"$VERIFICATION_TRC" 2>>"$VERIFICATION_TRC"&
         $memWinCmd pss_rx -k $oracle_sid -i $i3_base_dir_inode 1>>"$VERIFICATION_TRC" 2>>"$VERIFICATION_TRC"
   else
	$memWinCmd $PCS -k $oracle_sid -i $i3_base_dir_inode &
	$memWinCmd pss_rx -k $oracle_sid -i $i3_base_dir_inode &
   fi
fi

if [ "$fl_prepare" = true ] ; then
   if [ "$PREPARE_PID" -gt 0 ] ; then
      echo "prepare already up"
   else
      if [ "$fl_collect" = true ] ; then
	 sleep 2
      fi
      $memWinCmd pss_prepare -k $oracle_sid -i $i3_base_dir_inode &
   fi
fi

# Oracle Applications agent:

if [ "$pss_interpoint" -gt 0 ] && [ "$fl_collector_check" = false ] ; then
   case "$pss_interpoint" in
      1) $memWinCmd pss_apps.$pss_start_version $oracle_sid -agent -i $i3_base_dir_inode & ;;
      2) $memWinCmd pss_sap -k $oracle_sid -i $i3_base_dir_inode & ;;
   esac
fi

# Shay Z. 18/04/2007 - Titan case: 240-521-918 - avoid creating Sentry Indication file
# in Silent mode:
if [ "$fl_collector_check" = false ] ; then
   f_create_sentry_file "ORCOL" "$oracle_sid"
fi
