#! /bin/ksh 

export HOST=`uname -n`
export HOSTTYPE=`uname -s`
SED_CMD="sed 's#/#_#g'"

#
# Set a new value to BASE_SID_KEY:
function set_new_base_sid_key
{
   BASE_SID_KEY=`echo $1 | eval $SED_CMD | sed 's#_$##g' | sed 's#\-#_#g' | sed 's#\.#_#g'` 
}


#
# Get the input from the registry - via stdin:
# Side Effects: 
# Parameters: Te variables, which store the HOST and SID.
#
function getInputParms
{

   hostParmName=$1
   sidParmName=$2

   #read the first line, containing the base key for the sid:
   read BASE_SID_KEY

   if [ -z $BASE_SID_KEY ] ; then 
      echo "+ First input line is empty !"
      echo "+ FAIL"
      echo
   fi
   #
   # Split the input line into its components:
   #
   ORG_IFS=$IFS
   IFS="/"
   set -- $BASE_SID_KEY
   IFS=$ORG_IFS

   if [ "$1" = "" ] ; then 
	shift
   fi

   eval $hostParmName=$4
   eval $sidParmName=$5

   #
   #scan the rest of the input lines and set them into variables:
   #
   set_new_base_sid_key $BASE_SID_KEY

   while read key value ;
   do
      if [ ! -z "$key" ] && [ ! -z "$value" ] ; then
         key=`echo $key | eval $SED_CMD | sed 's#\-#_#g' | sed 's#\.#_#g'`
         eval "$key=\"$value\"";

         eval reg_str_val=\"'$'{$key}\"
if [ "$PRN_DBG" = "YES" ] ; then echo "key=$key val=$reg_str_val" ; fi
      fi
   done

}

#
# Get a string, which was accepted from the registry.
# Parameters:
# 1. The variable which is assigned the value.
# 2. Parameter name.
function getParmValue
{
   varName=$1
   keyName=`echo $2 | sed 's#\-#_#g' | sed 's#\.#_#g'`
   
   reg_parm_name="$BASE_SID_KEY"_$keyName

 if [ "$PRN_DBG" = "YES" ] ; then echo "reg_parm_name=$reg_parm_name" ; fi

   eval reg_parm_value=\"'$'{$reg_parm_name}\"

   # Verify that the value is not empty:
   if [ -z $reg_parm_value ] ; then
      fail "$2 UNKNOWN" "Value not found"
      exit 1
   fi
   
   
   eval $varName=\"$reg_parm_value\"

if [ "$PRN_DBG" = "YES" ] ; then echo "$varName=$reg_parm_value" ; fi
}


function sendVal {
    echo "+ /connection-pools/jdbc/pools/$SID-$HOST/$1" "$2"
    echo "+ SUCCESS"
    echo "+"
}

LOG_DIR="products/oracle/logs/"

# Read the Registry parameters to memory:
getInputParms HOST SID
HOST=${HOST}
getParmValue ORACLE_HOME home 


WORK_PATH="`pwd`/products/oracle"

if [ "`$WORK_PATH/install/root.sh -check`" != 0 ] ; then
   echo "+ 103: Login to %host% as root, and execute the file %file%"
   echo "+ PARAM file=$WORK_PATH/install/root.sh"
   echo "+ PARAM host=`uname -n`"
   echo "+"
   if [ `uname` = HP-UX ] ; then
      FS_NAME=`df . | awk '{print $1}'`
      echo "+ 104: Please make sure the file system %file% on which the collector is installed does not have nosuid set in /etc/fstab."
      echo "+ PARAM file=$FS_NAME"
      echo "+"
   fi;
fi

id_cmd="id"
if [ `uname` = SunOS ] ; then
  id_cmd="id -a"
fi;
oracle_group=`ls -ln $ORACLE_HOME/bin/oracle | awk '{print $4}'`
oracle_group_name=`ls -l $ORACLE_HOME/bin/oracle | awk '{print $4}'`
eval $id_cmd | grep "$oracle_group("
if [ $? != 0 ] && [ `uname -s` != "Linux" ] ; then
   echo "+ 101: Add the group %grp% to the user %user%."
   echo "+ PARAM grp=$oracle_group_name($oracle_group)"
   echo "+ PARAM user=$LOGNAME"
   echo "+"
fi   

###function testnfs {		!!!! THIS IS THE OLD FUNCTION !!!!
###    case "`uname -s`" in 
###	SunOS)     (df -k $1 | tail -1 ; /etc/mount -v) | awk 'BEGIN { getline; mount=$6; type="ERROR"; } $3 == mount { if ($5 == "nfs") type="NFS"; else type="LOCAL"; } END { print type }';;
###	HP-UX)     (bdf $1   | tail -1 ; /etc/mount -v) | awk 'BEGIN { getline; mount=$6; type="ERROR"; } $3 == mount { if ($5 == "nfs") type="NFS"; else type="LOCAL"; } END { print type }';; 
###	AIX)       (df -k $1 | tail -1 ; /etc/mount   ) | awk 'BEGIN { getline; mount=$7; type="ERROR"; } $3 == mount || $2 == mount { if ( $4 == "nfs3" ) type="NFS"; else type="LOCAL"; } END { print type }';; 
###	OSF1)      (df -k $1 | tail -1 ; /sbin/mount  ) | awk 'BEGIN { getline; mount=$6; type="ERROR"; } $3 == mount { if ($5 == "nfs") type="NFS"; else type="LOCAL"; } END { print type }';;
###	DYNIX/ptx) (df -k $1 | tail -1 ; /etc/mount -v) | awk 'BEGIN { getline; mount=$6; type="ERROR"; } $3 == mount { if ($5 == "nfs") type="NFS"; else type="LOCAL"; } END { print type }';; 
###	Linux)     (df -k $1 | tail -1 ; /bin/mount  )  | awk 'BEGIN { getline; mount=$6; type="ERROR"; } $3 == mount { if ($5 == "nfs") type="NFS"; else type="LOCAL"; } END { print type }';;
###	*) echo "unknown OS";; 
###    esac; 
###}

function testnfs 
{
	machine=`uname -s`
	
	## get i3 root directory
	##check_dir=`pwd`	

	## get the directory in config.xml
	check_dir=`grep "pss-temp-dir" ./products/oracle/config.xml | sed 's#</*pss-temp-dir>##g'`

	TMP=`echo $check_dir|awk -F'/' '{print $2}'`
	TMPD=`echo /$TMP`

	## x will contain "" only if the directory is LOCAL
	x="error"

	########SUN########
	if [ $machine = "SunOS" ]
	then
		dlist=`cat /etc/mnttab|grep -w nfs|awk '{print $2}'`
		x=`echo $dlist|grep $TMPD`

	########HP#########
	elif [ $machine = "HP-UX" ]
	then
		dlist=`cat /etc/mnttab|grep nfs|awk '{print $2}'`
		x=`echo $dlist|grep $TMPD`

	#######Alpha (OSF1)#######
	elif [ $machine = "OSF1" ]
	then
		dlist=`cat /etc/fstab|grep -w nfs|awk '{print $2}'`
		x=`echo $dlist|grep -w $TMPD`

	########AIX########
	elif [ $machine = "AIX" ]
	then
		# was -pw, changed to -p -w. when grep is used with -pw, it searches for "w" as a paragraph separator.
		# Tsiyon.
		dlist=`cat /etc/filesystems|grep -p -w nfs|awk '{print $1}'|grep '^/'|sed 's#:##g'`
		x=`echo $dlist|grep -w $TMPD`

	#######Linux#######
	elif [ $machine = "Linux" ]
	then
		dlist=`cat /etc/mtab |grep -w nfs |awk '{print $2}'`
		x=`echo $dlist|grep -w $TMPD`

	#####DYNIX/ptx#####
	elif [ $machine = "DYNIX/ptx" ]
	then
		dlist=`cat /etc/mnttab|grep nfs|awk '{print $2}'`
		x=`echo $dlist|grep $TMPD`
	fi
	
	echo $x
}

TMPF=/$SID.silent_rx.prc
TMPD=`grep "pss-temp-dir" $WORK_PATH/config.xml | sed 's#</*pss-temp-dir>##g'`$TMPF
if [ ${#TMPD} -gt 90 ] ; then
   echo "+ 105: Using temp directory having path longer than 90 characters might cause problems.Edit the file <i3 root dir>/products/oracle/config.xml, and set the value of pss-temp-dir to point to a directory with the shorter path"
   echo "+ PARAM config=$WORK_PATH/config.xml"
   echo "+ PARAM maxlen=$((90-${#TMPF}))"
   echo "+"
fi

echo ""
