#! /bin/ksh

##############################################################################
# Consider moving the code between the wide comments to an external file !!
##############################################################################

# the Registry key for the SID:
BASE_SID_KEY=


SED_CMD="sed 's#/#_#g'"

PRN_DBG=NO

function _fail {
    echo "+ FAIL"
    echo "+ $1:$2"
    if [ "${3:-}" != "" ] ; then
      echo "+ PARAM $3"
    fi
    if [ "${4:-}" != "" ] ; then
      echo "+ PARAM $4"
    fi
    echo "+"
}


#
# Set a new value to BASE_SID_KEY:
function set_new_base_sid_key
{
   BASE_SID_KEY=`echo $1 | eval $SED_CMD | sed 's#_$##g' | sed 's#\-#_#g' | sed 's#\.#_#g'` 
}


#
# Get the input from the registry - via stdin:
# Side Effects: 
# Parameters: Te variables, which store the HOST and SID.
#
function getInputParms
{
   hostParmName=$1
   sidParmName=$2

   # Read the connection type (sysdba or normal) 
   read key CONN_TYPE

   #read the first line, containing the base key for the sid:
   read BASE_SID_KEY

   if [ -z $BASE_SID_KEY ] ; then 
      _fail 600 "First input line is empty"
   fi
   #
   # Split the input line into its components:
   #
   ORG_IFS=$IFS
   IFS="/"
   set -- $BASE_SID_KEY
   IFS=$ORG_IFS

   if [ "$1" = "" ] ; then 
	shift
   fi

   eval $hostParmName=$4
   eval $sidParmName=$5

   #
   #scan the rest of the input lines and set them into variables:
   #
   set_new_base_sid_key $BASE_SID_KEY

   while read key value ;
   do
      if [ ! -z "$key" ] && [ ! -z "$value" ] ; then
         key=`echo $key | eval $SED_CMD | sed 's#\-#_#g' | sed 's#\.#_#g'`
         eval "$key=\"$value\"";

         eval reg_str_val=\"'$'{$key}\"
if [ "$PRN_DBG" = "YES" ] ; then echo "key=$key val=$reg_str_val" ; fi
      fi
   done

}

#
# Get a string, which was accepted from the registry.
# Parameters:
# 1. The variable which is assigned the value.
# 2. Parameter name.
function getParmValue
{
   varName=$1
   keyName=`echo $2 | sed 's#\-#_#g' | sed 's#\.#_#g'`
   
   reg_parm_name="$BASE_SID_KEY"_$keyName

 if [ "$PRN_DBG" = "YES" ] ; then echo "reg_parm_name=$reg_parm_name" ; fi

   eval reg_parm_value=\"'$'{$reg_parm_name}\"

   # Verify that the value is not empty:
   if [ -z $reg_parm_value ] ; then
      _fail 601 "Value not found: %val%" "val=$2"
      exit 1
   fi
   
   
   eval $varName=\"$reg_parm_value\"
if [ "$PRN_DBG" = "YES" ] ; then echo "$varName=$reg_parm_value" ; fi
}


#
# Create a directory if it does not exist.
# If creation fails - generate an error message and exit:
function mkdir_if_missing
{
   newDir=$1;
   if [ ! -d $newDir ] ; then
      mkdir $newDir 2>/dev/null
      if [ $? != 0 ] ; then
         _fail 602 "Unable to create directory: %dir%" "dir=$newDir"
         exit 1
      fi
   fi
}

function run_sqlplus
{
# Perform verification of the DBA user provided
if [ "$CONN_TYPE" = "SYSDBA" ] ; then
	if [ "$PRN_DBG" = "YES" ] ; then 
		echo "Executing command: @products/oracle/install/I4OConnectSysdbaVerify.sql $DBA ***** $SID verify_instance $DB_VER $INP_HOST YES UNIX"
	fi
	$ORACLE_HOME/bin/sqlplus -s /nolog @products/oracle/install/I4OConnectSysdbaVerify.sql $DBA $DBA_PASS $SID verify_instance $DB_VER $INP_HOST YES UNIX >$OUT 2>$ERROUT
else
	if [ "$PRN_DBG" = "YES" ] ; then 
		echo "Executing command: @products/oracle/install/I4OConnectNormalVerify.sql $DBA ***** $SID verify_instance $DB_VER $INP_HOST $CHECK_PRIVILEGES UNIX"
	fi
	$ORACLE_HOME/bin/sqlplus -s /nolog @products/oracle/install/I4OConnectNormalVerify.sql $DBA $DBA_PASS $SID verify_instance $DB_VER $INP_HOST $CHECK_PRIVILEGES UNIX >$OUT 2>$ERROUT
fi
if [ $? != 0 ] ; then
	errorFound=YES
fi
}

##############################################################################

#### LOG_DIR="products/oracle/logs/"
LOG_DIR="logs/"

# Read the Registry parameters to memory:
getInputParms INP_HOST INP_SID
HOST=${INP_HOST}
SID=${INP_SID}

# Load the Input parameters into variables
# assign local varialbles:
getParmValue DBA        connection_dba_user 
getParmValue DBA_PASS   connection_dba_password 
getParmValue DB_VER     connection_version 

#need to get oracle_home from registry...
getParmValue ORACLE_HOME home 
getParmValue PORT        connection_oracle_listener_port 
export ORACLE_HOME
export PORT
export ORACLE_SID=$SID
HOST_PHYSICAL_NAME="$server_full_name"
export LD_LIBRARY_PATH=$ORACLE_HOME/lib:$LD_LIBRARY_PATH
export LD_LIBRARY_PATH_64=$ORACLE_HOME/lib:$LD_LIBRARY_PATH_64
export SHLIB_PATH=$ORACLE_HOME/lib:$SHLIB_PATH
export LIBPATH=$ORACLE_HOME/lib:$LIBPATH

OUT=${LOG_DIR}oracle.verify.instance.$HOST.$SID.out
ERROUT=${LOG_DIR}oracle.verify.instance.$HOST.$SID.err.out
errorFound=NO

CHECK_PRIVILEGES=YES
if [ "$server_operation" = "relocate" -o "$server_operation" = "rename" -o "$instance_admin_mode" = "move" -o "$instance_admin_mode" = "rename" -o "$instance_admin_mode" = "rename_move" ]; then
	CHECK_PRIVILEGES=NO
fi

if [ "$setup_mode" = "edit" -o "$manual_schema" = "true" ]; then
	CHECK_PRIVILEGES=NO
fi
# Check the Oracle Home exists
if [ ! -d $ORACLE_HOME ] ; then
   _fail 603 "Oracle home directory %dir% does not exist" "dir=$ORACLE_HOME"
   return
fi

# Check that the Sqlplus executable exists
if [ ! -f $ORACLE_HOME/bin/sqlplus ] ; then
   _fail 604 "Cannot execute SQL*Plus. %file% does not exist" "file=$ORACLE_HOME/bin/sqlplus"
   return
fi

# Check group of i3 user
id_cmd="id"
if [ `uname` = SunOS ] ; then
  id_cmd="id -a"
fi;
oracle_group=`ls -ln $ORACLE_HOME/bin/oracle | awk '{print $4}'`
oracle_group_name=`ls -l $ORACLE_HOME/bin/oracle | awk '{print $4}'`
$id_cmd | grep "$oracle_group(" > /dev/null

if [ $? != 0 ] && [ `uname -s` != "Linux" ] ; then
  _fail 763 "user group is not like oracle group: %oracle_group%" "oracle_group=$oracle_group_name($oracle_group)"
  return
fi

if [ ! -x $ORACLE_HOME/bin/sqlplus ] ; then
   _fail 681 "Cannot execute %file% - permissions denied." "file=$ORACLE_HOME/bin/sqlplus"
   return
fi

# Check that the tnsping executable exists
if [ ! -f $ORACLE_HOME/bin/tnsping ] ; then
   _fail 643 "Cannot execute tnsping. %file% does not exist" "file=$ORACLE_HOME/bin/tnsping"
   return
fi

if [ ! -x $ORACLE_HOME/bin/tnsping ] ; then
   _fail 681 "Cannot execute %file% - permissions denied." "file=$ORACLE_HOME/bin/tnsping"
   return
fi

# Try to tnsping the listener
if [ "$PRN_DBG" = "YES" ] ; then 
	echo "Executing command: $ORACLE_HOME/bin/tnsping (DESCRIPTION=(ADDRESS=(PROTOCOL=tcp)(HOST=$HOST_PHYSICAL_NAME)(PORT=$PORT)))"
fi
$ORACLE_HOME/bin/tnsping "(DESCRIPTION=(ADDRESS=(PROTOCOL=tcp)(HOST=$HOST_PHYSICAL_NAME)(PORT=$PORT)))"  >$OUT 2>$ERROUT
if [ $? != 0 ] ; then
	errorFound=YES
fi


if [ "$errorFound" = "NO" ] ; then
	run_sqlplus
	if [ "$errorFound" = "YES" ] ; then
#	retry with tns connection
		errorFound=NO
		export TWO_TASK="(DESCRIPTION=(ADDRESS_LIST=(ADDRESS=(PROTOCOL=TCP)(Host=$HOST_PHYSICAL_NAME)(Port=$PORT)))(CONNECT_DATA=(SID=$SID)))"
		run_sqlplus
	fi
fi


# Check the output file
if [ "$errorFound" != "NO" ] ; then
   oraerr=`egrep "(ORA)|(SP2)|(TNS)-" $OUT`
   if [ `grep -c "ORA-12505" $OUT` != 0 ] ; then
      _fail 611 "Either Oracle listener port or Oracle SID are incorrect. %detail%" "detail=$oraerr"
   elif [ `grep -c "TNS-12541" $OUT` != 0 ] ; then
      _fail 612 "Oracle listener port is incorrect. %detail%" "detail=$oraerr"
   elif [ `grep -c "ORA-12541" $OUT` != 0 ] ; then
      _fail 612 "Oracle listener port is incorrect. %detail%" "detail=$oraerr"
   elif [ `grep -c "ORA-01017" $OUT` != 0 ] ; then
      _fail 613 "Cannot connect to Oracle. %detail%" "detail=$oraerr"
   elif [ `grep -c "ORA-12560" $OUT` != 0 ] ; then
     _fail 6622 "ORA-12560: TNS:protocol adapter error . %detail%" "detail=$oraerr"
   else     
      if [ "$oraerr" = "" ] ; then 
         oraerr=`tail $ERROUT`
      fi
      _fail 613 "Unable to connect to Oracle. %detail%" "detail=$oraerr"
   fi
   return
fi

# Check version
cur_version=`grep "version=" $OUT 2>/dev/null|sed 's/version=//1'|sed 's/\"//g'`
if [ "$cur_version" != "" ] ; then
	echo checking against supported
	if [ `grep -v "^#" products/oracle/mapping/supported-versions.txt| grep -c "\"$cur_version\""` = 0 ] ; then
            _fail 607 "The Oracle version %version% is not supported" "version=$cur_version"
	fi
fi

grep -v "^$" $OUT

echo "+ OK"
echo
